# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/condition.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0systemathics/apis/type/shared/v1/condition.proto\x12 systemathics.apis.type.shared.v1\"\x91\x01\n\tCondition\x12\x14\n\x05value\x18\x01 \x01(\tR\x05value\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x18\n\x07\x63omment\x18\x03 \x01(\tR\x07\x63omment\x12\x18\n\x07regular\x18\x04 \x01(\x08R\x07regular\x12\x18\n\x07\x61uction\x18\x05 \x01(\x08R\x07\x61uctionB\xdb\x01\n$com.systemathics.apis.type.shared.v1B\x0e\x43onditionProtoP\x01\xa2\x02\x04SATS\xaa\x02 Systemathics.Apis.Type.Shared.V1\xca\x02 Systemathics\\Apis\\Type\\Shared\\V1\xe2\x02,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\xea\x02$Systemathics::Apis::Type::Shared::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.type.shared.v1.condition_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$com.systemathics.apis.type.shared.v1B\016ConditionProtoP\001\242\002\004SATS\252\002 Systemathics.Apis.Type.Shared.V1\312\002 Systemathics\\Apis\\Type\\Shared\\V1\342\002,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\352\002$Systemathics::Apis::Type::Shared::V1'
  _globals['_CONDITION']._serialized_start=87
  _globals['_CONDITION']._serialized_end=232
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from systemathics.apis.services.daily.v1 import daily_open_interest_pb2 as systemathics_dot_apis_dot_services_dot_daily_dot_v1_dot_daily__open__interest__pb2


class DailyOpenInterestsServiceStub(object):
    """Called to request daily OpenInterest data. 
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DailyOpenInterests = channel.unary_unary(
                '/systemathics.apis.services.daily.v1.DailyOpenInterestsService/DailyOpenInterests',
                request_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v1_dot_daily__open__interest__pb2.DailyOpenInterestsRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v1_dot_daily__open__interest__pb2.DailyOpenInterestsResponse.FromString,
                )


class DailyOpenInterestsServiceServicer(object):
    """Called to request daily OpenInterest data. 
    """

    def DailyOpenInterests(self, request, context):
        """Gets daily historical open interest
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DailyOpenInterestsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'DailyOpenInterests': grpc.unary_unary_rpc_method_handler(
                    servicer.DailyOpenInterests,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v1_dot_daily__open__interest__pb2.DailyOpenInterestsRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v1_dot_daily__open__interest__pb2.DailyOpenInterestsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'systemathics.apis.services.daily.v1.DailyOpenInterestsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DailyOpenInterestsService(object):
    """Called to request daily OpenInterest data. 
    """

    @staticmethod
    def DailyOpenInterests(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.daily.v1.DailyOpenInterestsService/DailyOpenInterests',
            systemathics_dot_apis_dot_services_dot_daily_dot_v1_dot_daily__open__interest__pb2.DailyOpenInterestsRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_daily_dot_v1_dot_daily__open__interest__pb2.DailyOpenInterestsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily_analytics/v1/daily_macd.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>systemathics/apis/services/daily_analytics/v1/daily_macd.proto\x12-systemathics.apis.services.daily_analytics.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\"\xff\x01\n\x10\x44\x61ilyMacdRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12S\n\rdate_interval\x18\x02 \x01(\x0b\x32..systemathics.apis.type.shared.v1.DateIntervalR\x0c\x64\x61teInterval\x12\x12\n\x04long\x18\x03 \x01(\x05R\x04long\x12\x14\n\x05short\x18\x04 \x01(\x05R\x05short\x12\x1e\n\nadjustment\x18\x05 \x01(\x08R\nadjustment\"e\n\x11\x44\x61ilyMacdResponse\x12P\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32<.systemathics.apis.services.daily_analytics.v1.DailyMacdDataR\x04\x64\x61ta\"\x8a\x01\n\rDailyMacdData\x12%\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value\x12\x12\n\x04macd\x18\x03 \x01(\x01R\x04macd\x12\x14\n\x05short\x18\x04 \x01(\x01R\x05short\x12\x12\n\x04long\x18\x05 \x01(\x01R\x04long2\xc5\x01\n\x10\x44\x61ilyMacdService\x12\xb0\x01\n\tDailyMacd\x12?.systemathics.apis.services.daily_analytics.v1.DailyMacdRequest\x1a@.systemathics.apis.services.daily_analytics.v1.DailyMacdResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/daily-analytics/macdB\x98\x02\n1com.systemathics.apis.services.daily_analytics.v1B\x0e\x44\x61ilyMacdProtoP\x01\xa2\x02\x04SASD\xaa\x02,Systemathics.Apis.Services.DailyAnalytics.V1\xca\x02,Systemathics\\Apis\\Services\\DailyAnalytics\\V1\xe2\x02\x38Systemathics\\Apis\\Services\\DailyAnalytics\\V1\\GPBMetadata\xea\x02\x30Systemathics::Apis::Services::DailyAnalytics::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.daily_analytics.v1.daily_macd_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n1com.systemathics.apis.services.daily_analytics.v1B\016DailyMacdProtoP\001\242\002\004SASD\252\002,Systemathics.Apis.Services.DailyAnalytics.V1\312\002,Systemathics\\Apis\\Services\\DailyAnalytics\\V1\342\0028Systemathics\\Apis\\Services\\DailyAnalytics\\V1\\GPBMetadata\352\0020Systemathics::Apis::Services::DailyAnalytics::V1'
  _globals['_DAILYMACDSERVICE'].methods_by_name['DailyMacd']._options = None
  _globals['_DAILYMACDSERVICE'].methods_by_name['DailyMacd']._serialized_options = b'\202\323\344\223\002\032\022\030/v1/daily-analytics/macd'
  _globals['_DAILYMACDREQUEST']._serialized_start=273
  _globals['_DAILYMACDREQUEST']._serialized_end=528
  _globals['_DAILYMACDRESPONSE']._serialized_start=530
  _globals['_DAILYMACDRESPONSE']._serialized_end=631
  _globals['_DAILYMACDDATA']._serialized_start=634
  _globals['_DAILYMACDDATA']._serialized_end=772
  _globals['_DAILYMACDSERVICE']._serialized_start=775
  _globals['_DAILYMACDSERVICE']._serialized_end=972
# @@protoc_insertion_point(module_scope)
